==> foundation-ui-components-1.15.0.tgz: package/src/common/nav-tab/NavTitles.tsx <==
import { NavTabs, NsLink, NsTypography } from '../';
import { NavTabBox, NavTabUnderLine, NavTitlesBox } from './NsNavTab.styled';
import { Show } from '../utility';

type NavTitlesProps = {
    tabs: NavTabs[];
    // eslint-disable-next-line no-unused-vars
    setActive(_x: string): void;
    active: string | null;
    tabTitleClassName?: string;
};

export const NavTitles = ({ tabs, setActive, active, tabTitleClassName }: NavTitlesProps) => {
    const NavTitleTypography = (tab: NavTabs) => (
        <NsTypography
            variant={tab.textVariant}
            additionalProps={{ ...tab?.liveTag }}
            className={`${tabTitleClassName} ${!active ? 'opacity-8' : ''}`}
            color={tab.tabName === active ? tab.activeColor : tab.color}
        >
            {tab.tabName}
        </NsTypography>
    );

    return (
        <NavTitlesBox className="desktop-nav-titles">
            {tabs?.map((tab) => {
                const handleMouseEnter = () => {
                    setActive(tab.tabName);
                };
                return (
                    <div
                        key={tab?.tabName}
                        data-testid={tab?.tabName}
                        className="relative cursor-pointer"
                        onMouseEnter={handleMouseEnter}
                    >
                        <NavTabBox
                            className="nav-tab-box"
                            data-testid={tab.tabName + '-list'}
                            transition={{
                                duration: 0.3,
                            }}
                            animate
                        >
                            {tab?.tabLink ? (
                                <NsLink href={tab.tabLink} underlineOnHover={false}>
                                    <NavTitleTypography {...tab} />
                                </NsLink>
                            ) : (
                                <NavTitleTypography {...tab} />
                            )}
                        </NavTabBox>
                        <Show when={active === tab.tabName}>
                            <NavTabUnderLine data-testid="underline" layoutId="underline" color={tab.activeColor} />
                        </Show>
                    </div>
                );
            })}
        </NavTitlesBox>
    );
};

==> foundation-ui-components-1.24.1.tgz: package/src/common/nav-tab/NavTitles.tsx <==
import { NavTabs, NsLink, NsTypography } from '../';
import { NavTabBox, NavTabUnderLine, NavTitlesBox } from './NsNavTab.styled';
import { Show } from '../utility';

type NavTitlesProps = {
    tabs: NavTabs[];
    // eslint-disable-next-line no-unused-vars
    setActive(_x: string): void;
    active: string | null;
    tabTitleClassName?: string;
};

export const NavTitles = ({ tabs, setActive, active, tabTitleClassName }: NavTitlesProps) => {
    const NavTitleTypography = (tab: NavTabs) => (
        <NsTypography
            variant={tab.textVariant}
            additionalProps={{ ...tab?.liveTag }}
            className={`${tabTitleClassName} ${!active ? 'opacity-8' : ''}`}
            color={tab.tabName === active ? tab.activeColor : tab.color}
            noSpacing
        >
            {tab.tabName}
        </NsTypography>
    );

    return (
        <NavTitlesBox className="desktop-nav-titles">
            {tabs?.map((tab) => {
                const handleMouseEnter = () => {
                    setActive(tab.tabName);
                };
                return (
                    <div
                        key={tab?.tabName}
                        data-testid={tab?.tabName}
                        className="relative cursor-pointer"
                        onMouseEnter={handleMouseEnter}
                    >
                        <NavTabBox
                            className="nav-tab-box"
                            data-testid={tab.tabName + '-list'}
                            transition={{
                                duration: 0.3,
                            }}
                            animate
                        >
                            {tab?.tabLink ? (
                                <NavTitleTypography {...tab} >
                                    <NsLink href={tab.tabLink} underlineOnHover={false} />
                                </NavTitleTypography>
                            ) : (
                                <NavTitleTypography {...tab} />
                            )}
                        </NavTabBox>
                        <Show when={active === tab.tabName}>
                            <NavTabUnderLine data-testid="underline" layoutId="underline" color={tab.activeColor} />
                        </Show>
                    </div>
                );
            })}
        </NavTitlesBox>
    );
};
